package Mail::DMARC::Report::AFRF;
{
  $Mail::DMARC::Report::AFRF::VERSION = '0.20130506';
}
use strict;
use warnings;

use parent 'Mail::DMARC::Report';

1;
# ABSTRACT: an AFRF report


=pod

=head1 NAME

Mail::DMARC::Report::AFRF - an AFRF report

=head1 VERSION

version 0.20130506

=head1 DESCRIPTION

=head1 AUTHORS

=over 4

=item *

Matt Simerson <msimerson@cpan.org>

=item *

Davide Migliavacca <shari@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by The Network People, Inc..

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

